@@ -1,7 +1,6 @@
 import time
-from  multiprocessing import  current_process
 
-from .variables import pid_files, task_pidfile, sync_pidfile, publish_pidfile
+from .variables import publish_pidfile
 from .public import write_pid
 
 def publish_metrc():
@@ -13,5 +12,5 @@ def publish_metrc():
 
 
 def publish_runner(master_data):
-    write_pid(current_process().pid, publish_pidfile)
+    write_pid(publish_pidfile)
     publish_metrc()
\ No newline at end of file
