@@ -50,15 +50,18 @@ def register(server, label, tag, timeout):
 @click.option("--sessionId", required=True, help="session id")
 def run(server, workerid, sessionid, timeout):
     master_data = {"server": server, "workerId": workerid, "sessionId": sessionid, "timeout": timeout}
-    task_process = Process(target=task_runner, daemon=True, args=(master_data,))
-    publish_process = Process(target=publish_runner, daemon=True, args=(master_data,))
-    sync_process = Process(target=sync_runner, daemon=True, args=(master_data,))
-    task_process.start()
-    publish_process.start()
-    sync_process.start()
-    sync_process.join()
-    publish_process.join()
-    publish_process.join()
+    task_proc = Process(target=task_runner, args=(master_data,))
+    publish_proc = Process(target=publish_runner, args=(master_data,))
+    sync_proc = Process(target=sync_runner, args=(master_data,))
+    task_proc.daemon = True
+    publish_proc.daemon = True
+    sync_proc.daemon = True
+    task_proc.start()
+    publish_proc.start()
+    sync_proc.start()
+    sync_proc.join()
+    publish_proc.join()
+    publish_proc.join()
 
 cli.add_command(register)
 cli.add_command(run)
